# Delta Core

## prerequisites

To execute locally
```
git submodule update --init --recursive --remote
```
## How to build ?

```
docker build -t registry.gael.fr/gael10/delta/software/delta-core/delta-run .
```